// Copyright IBM Corp. 2015,2016. All Rights Reserved.
// Node module: wlpn-cli-health-analyzer
// US Government Users Restricted Rights - Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.

'use strict';

var HealthAnalyzer = require('../lib/health-analyzer');
var tap = require('tap');

tap.test('health-analyzer', function(t) {
  var options = {
    serverName: 'hello',
    serverPath: '/home/user/wlpn',
    adminPort: 9081,
    hostName: 'system.raleigh.ibm.com',
    userDir: '/home/user/wlpn',
  };
  var sentMessage = null;
  var onCallback = null;
  options.manager = {
    get: function(name) {
      if (name === 'runner') {
        return function() {
          return {
            on: function(request, cb) { onCallback = cb; },
          };
        };
      } else if (name === 'controller') {
        return function() {
          return {
            request: function(msg) { sentMessage = msg; },
          };
        };
      };
    },
    app: {
      use: function() {},
    },
  };
  t.test('start-stop', function(t) {
    options.manager.get();
    var analyzer = new HealthAnalyzer(options);
    analyzer.start({}, function() {});
    t.assert(analyzer);
    t.end();
  });

  t.test('send', function(t) {
    options.manager.get();
    var analyzer = new HealthAnalyzer(options);
    analyzer.start({}, function() {});
    t.assert(analyzer);
    sentMessage = null;
    analyzer.sendMessage('target type', 'message');
    if (sentMessage == null) {
      t.fail(sentMessage);
    } else {
      t.pass(sentMessage);
    }
    t.end();
  });

  t.test('receive', function(t) {
    var receivedMessage = null;
    var receiveCallback = null;
    var app = {
      post: function(root, cb) {
        receiveCallback = cb;
      },
      use: function() {},
    };
    var plugin = {
      receiveMessage: function(message) {
        receivedMessage = message;
      },
      name: 'plugin',
    };
    var message = {
      target: 'target',
      targettype: 'plugin',
      message: JSON.stringify({message: 'message'}),
    };
    options.manager.get();
    var analyzer = new HealthAnalyzer(options);
    analyzer._app = app;
    analyzer._listeners['plugin'] = plugin;
    analyzer.start({}, function() {});
    t.assert(analyzer);
    receivedMessage = null;
    receiveCallback({body: message}, {send: function() {}});
    if (receivedMessage == null) {
      t.fail(receivedMessage);
    } else {
      t.pass(receivedMessage);
    }
    t.end();
  });

  t.test('notify', function(t) {
    var notifiedData = null;
    var plugin = {
      update: function(message) {
        notifiedData = message;
      },
      getName: function() {
        return ('plugin');
      },
    };
    var data = {
      target: 'target',
      targettype: 'plugin',
      message: JSON.stringify({message: 'message'}),
    };

    var analyzer = new HealthAnalyzer(options);
    analyzer._listeners.plugin = plugin;
    analyzer.start({}, function() {});
    analyzer.addEventListener('appmetrics:gc', plugin.update);
    t.assert(analyzer);
    notifiedData = null;
    onCallback({cmd: 'appmetrics:gc', data: data});
    if (notifiedData == null) {
      t.fail(notifiedData);
    } else {
      t.pass(notifiedData);
    }
    t.end();
  });

  t.end();
});
