// Copyright IBM Corp. 2015,2016. All Rights Reserved.
// Node module: wlpn-cli-health-analyzer
// US Government Users Restricted Rights - Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.

'use strict';

var MemoryLeak = require('../lib/memory-leak');
var tap = require('tap');

tap.test('memory-leak', function(t) {
  var options = {};
  var statsCollector = {
    sendMessage: function(msg) {
      t.ok(msg, 'condition trigered');
      triggered = true;
    },
    addEventListener: function(cmd, listener) {
    },
  };

  var initMsg = {
    operation: 'set',
  };

  var endMsg = {
    operation: 'unset',
  };

  var triggered = false;

  t.test('start-stop', function(t) {
    var analyzer = new MemoryLeak(options, statsCollector);
    t.assert(analyzer);
    analyzer.receiveMessage(JSON.stringify(initMsg));
    analyzer.receiveMessage(JSON.stringify(endMsg));
    t.end();
  });

  t.test('trigger', function(t) {
    var analyzer = new MemoryLeak(options, statsCollector);
    t.assert(analyzer);
    analyzer.receiveMessage(JSON.stringify(initMsg));
    triggered = false;
    var i;
    for (i = 0; i < 105; i++) {
      var data = {
        type: 'S',
        time: 500 + i * 20,
        used: 50000000 + i * 300,
        size: 100000000,
      };
      analyzer.update(data);
    }
    if (triggered) {
      t.pass('condition triggered');
    } else {
      t.fail('condition not triggered');
    }
    t.end();
  });

  t.test('non-trigger', function(t) {
    var analyzer = new MemoryLeak(options, statsCollector);
    t.assert(analyzer);
    analyzer.receiveMessage(JSON.stringify(initMsg));
    triggered = false;
    var i;
    for (i = 0; i < 105; i++) {
      var data = {
        type: 'S',
        time: 500 + i * 20,
        used: 50000000 - i * 30,
        size: 100000000,
      };
      analyzer.update(data);
    }
    if (!triggered) {
      t.pass('condition triggered');
    } else {
      t.fail('condition not triggered');
    }
    t.end();
  });

  t.end();
});
