// Copyright IBM Corp. 2015,2016. All Rights Reserved.
// Node module: wlpn-cli-health-analyzer
// US Government Users Restricted Rights - Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.

'use strict';

var tap = require('tap');
var MemoryUsage = require('../lib/memory-usage');

tap.test('memory-usage', function(t) {
  var statsCollector = {
    sendMessage: function(msg) {
      triggered = true;
    },
    addEventListener: function(cnd, listener) {
    },
  };

  var options = {
    logger: {
      log: function() {},
      error: function() {},
    },
  };

  var triggered = false;

  var initMsg = {
    thresholdPercent: '40',
    maxTime: '1',
  };

  t.test('invalid', function(t) {
    var analyzer = new MemoryUsage(options, statsCollector);
    t.assert(analyzer);
    analyzer.receiveMessage('invalid message');
    if (analyzer._memThresPercent === 0)
      t.pass();
    else
      t.fail();
    t.end();
  });

  t.test('start', function(t) {
    var analyzer = new MemoryUsage(options, statsCollector);
    t.assert(analyzer);
    analyzer.receiveMessage(JSON.stringify(initMsg));
    t.end();
  });

  t.test('process', function(t) {
    var analyzer = new MemoryUsage(options, statsCollector);
    t.assert(analyzer);
    analyzer.receiveMessage(JSON.stringify(initMsg));
    var i;
	// Send 50% usage stats for a whlie
    for (i = 0; i < 25; i++) {
      var data = {
        type: 'S',
        used: 50,
        size: 100,
      };
      analyzer.update(data);
    }
    if (triggered) {
      t.pass('condition triggered');
    } else {
      t.fail('condition not triggered');
    }
    analyzer.receiveMessage(JSON.stringify(initMsg));
    triggered = false;
    for (i = 0; i < 25; i++) {
      data = {
        type: 'S',
        used: 30,
        size: 100,
      };
      analyzer.update(data);
    }
    if (!triggered) {
      t.pass('condition triggered');
    } else {
      t.fail('condition not triggered');
    }
    triggered = false;
    analyzer.receiveMessage(JSON.stringify(initMsg));
    data = {
      type: 'S',
      used: 50,
      size: 100,
    };
    analyzer.update(data);
    setTimeout(function() {
      t.end();
    }, 2000);
  });

  t.test('check', function(t) {
    if (triggered) {
      t.pass('condition triggered');
    } else {
      t.fail('condition not triggered');
    }
    t.end();
  });

  t.test('test gets', function(t) {
    var analyzer =
    new MemoryUsage(options, {sendMessage: {bind: function() {}},
                              addEventListener: function() {}});
    var servConditionName = analyzer.name;
    t.equals(servConditionName, 'MemoryUsageServerCondition');
    t.end();
  });

  t.end();
});
